@@ -23,8 +23,7 @@
 class QLineEdit;
 class QCheckBox;
 class QSpinBox;
-namespace NoteShared
-{
+namespace NoteShared {
 class NoteNetworkConfigWidgetPrivate;
 class NOTESHARED_EXPORT NoteNetworkConfigWidget : public QWidget
 {
@@ -45,8 +44,8 @@ class NOTESHARED_EXPORT NoteNetworkConfig : public KCModule
 public:
     NoteNetworkConfig(QWidget *parent);
     /** Reimplemented from KCModule. */
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
 };
 }
 
